@@ -11,7 +11,7 @@ import tornado.ioloop
 import tornado.testing
 import tornado.web
 
-from webargs import fields, missing
+from webargs import fields, missing, validate
 from webargs.core import json, parse_json
 from webargs.tornadoparser import (
     WebArgsTornadoMultiDictProxy,
@@ -41,7 +41,7 @@ value = "value"
 
 
 class AuthorSchema(ma.Schema):
-    name = fields.Str(load_default="World", validate=lambda n: len(n) >= 3)
+    name = fields.Str(load_default="World", validate=validate.Length(min=3))
     works = fields.List(fields.Str())
 
 
@@ -211,14 +211,17 @@ class TestFilesArgs:
 
 class TestErrorHandler:
     def test_it_should_raise_httperror_on_failed_validation(self):
-        args = {"foo": fields.Field(validate=lambda x: False)}
+        def always_fail(_):
+            raise ma.ValidationError("oops")
+
+        args = {"foo": fields.Raw(validate=always_fail)}
         with pytest.raises(tornado.web.HTTPError):
             parser.parse(args, make_json_request({"foo": 42}))
 
 
 class TestParse:
     def test_it_should_parse_query_arguments(self):
-        attrs = {"string": fields.Field(), "integer": fields.List(fields.Int())}
+        attrs = {"string": fields.Raw(), "integer": fields.List(fields.Int())}
 
         request = make_get_request(
             [("string", "value"), ("integer", "1"), ("integer", "2")]
@@ -230,7 +233,7 @@ class TestParse:
         assert parsed["string"] == value
 
     def test_it_should_parse_form_arguments(self):
-        attrs = {"string": fields.Field(), "integer": fields.List(fields.Int())}
+        attrs = {"string": fields.Raw(), "integer": fields.List(fields.Int())}
 
         request = make_form_request(
             [("string", "value"), ("integer", "1"), ("integer", "2")]
@@ -298,7 +301,7 @@ class TestParse:
         assert parsed["integer"] == [1, 2]
 
     def test_it_should_parse_required_arguments(self):
-        args = {"foo": fields.Field(required=True)}
+        args = {"foo": fields.Raw(required=True)}
 
         request = make_json_request({})
 
@@ -319,7 +322,7 @@ class TestUseArgs:
         class Handler:
             request = make_json_request({"key": "value"})
 
-            @use_args({"key": fields.Field()})
+            @use_args({"key": fields.Raw()})
             def get(self, *args, **kwargs):
                 assert args[0] == {"key": "value"}
                 assert kwargs == {}
@@ -334,7 +337,7 @@ class TestUseArgs:
         class Handler:
             request = make_json_request({"key": "value"})
 
-            @use_kwargs({"key": fields.Field()})
+            @use_kwargs({"key": fields.Raw()})
             def get(self, *args, **kwargs):
                 assert args == ()
                 assert kwargs == {"key": "value"}
@@ -346,10 +349,14 @@ class TestUseArgs:
         assert result is True
 
     def test_it_should_be_validate_arguments_when_validator_is_passed(self):
+        def validator(args):
+            if args["foo"] <= 42:
+                raise ma.ValidationError("invalid")
+
         class Handler:
             request = make_json_request({"foo": 41})
 
-            @use_kwargs({"foo": fields.Int()}, validate=lambda args: args["foo"] > 42)
+            @use_kwargs({"foo": fields.Int()}, validate=validator)
             def get(self, args):
                 return True
 
